全国公共资源交易平台

#### 2018年中央财政大中型水库移民后期扶持资金（清算节余）东平县商老庄乡大安山村码头配套等16个项目施工及监理中标公示

发布时间：2020-04-22 18:20信息来源：泰安市公共资源电子交易平台原文链接地址

一、招标人：东平县移民服务中心

地址：东平县城佛山街

联系人：王科长

联系方式：0538-2873216

代理机构：山东龙融招投标代理有限公司

地 址：泰安市虎山东路畜牧局东综合楼三楼

项目经理：张振杰

联系方式：17753897991

二、项目名称：2018年中央财政大中型水库移民后期扶持资金（清算节余）东平县商老庄乡大安山村码头配套等16个项目

项目编号：SDGP370923202002000064

三、招标公告期限：2020年4月1日到2020年4月8日

四、采购方式：公开招标

五、中标情况：

包号 | 预中标供应商名称 | 地址 | 预中标标的名称 | 数量 | 报价 （万元） | 服务要求
1 | 东平县东平湖开发工程处 | 泰安市东平县城佛山街西首 | 第一标段主要内容：东平县商老庄乡大安山村、戴庙镇土山村等5个项目施工 | 1宗 | 265.946111 | 响应招标文件要求
2 | 东平县东平湖开发工程处 | 泰安市东平县城佛山街西首 | 东平县商老庄乡东平街道王村、州城街道新湖苑社区等11个项目施工 | 1宗 | 457.176795 | 响应招标文件要求
3 | 泰安瑞兴工程咨询有限公司 | 泰安市擂鼓石大街659号- | 东平县商老庄乡大安山村、戴庙镇土山村等5个项目监理 | 1宗 | 6.6665 | 响应招标文件要求
4 | 山东天柱建设监理咨询有限公司 | 聊城市经济技术开发区东昌东路177号 | 东平县商老庄乡东平街道王村、州城街道新湖苑社区等11个项目监理 | 1宗 | 11.390125 | 响应招标文件要求

六、评标委员会成员名单：赵霞、赵瑜、李月霞、王大勇、张新孔

七、采购小组成员评审结果

第一标段

序号 | 投标单位名称 | 投标总报价（万元） | 报价分 | 技术得分汇总得分 | 总得分 | 排名
1 | 东平县东平湖开发工程处 | 265.946111 | 44.89 | 50.88 | 95.77 | 1
2 | 山东禹道水利建设工程有限公司 | 266.520642 | 44.78 | 46.18 | 90.96 | 2
3 | 济宁众恒建筑工程有限公司 | 264.274994 | 44.26 | 45.04 | 89.30 | 6
4 | 凯鲁集团有限公司 | 266.522367 | 44.78 | 43.72 | 88.50 | 7
5 | 济宁诚信园林绿化有限公司 | 265.182518 | 44.61 | 44.74 | 89.35 | 5
6 | 东平开元建设工程有限公司 | 266.996255 | 44.43 | 45.58 | 90.01 | 4
7 | 泰安润泽建设工程有限公司 | 267.708761 | 43.89 | 46.14 | 90.03 | 3

第二标段

序号 | 投标单位名称 | 投标总报价（万元） | 报价分 | 技术得分汇总得分 | 总得分 | 排名
1 | 东平县东平湖开发工程处 | 457.176795 | 44.96 | 50.90 | 95.86 | 1
2 | 山东禹道水利建设工程有限公司 | 455.603475 | 44.11 | 46.18 | 90.29 | 3
3 | 济宁众恒建筑工程有限公司 | 451.713747 | 44.76 | 45.08 | 89.84 | 4
4 | 凯鲁集团有限公司 | 456.310244 | 44.61 | 43.70 | 88.31 | 6
5 | 济宁诚信园林绿化有限公司 | 454.006754 | 44.02 | 44.72 | 88.74 | 5
6 | 泰安润泽建设工程有限公司 | 458.018099 |